# - Try to find VLC library
# Once done this will define
#
#  VLC_FOUND - system has VLC
#  VLC_INCLUDE_DIR - The VLC include directory
#  VLC_LIBRARIES - The libraries needed to use VLC
#  VLC_DEFINITIONS - Compiler switches required for using VLC
#
# Copyright (C) 2008, Tanguy Krotoff <tkrotoff@gmail.com>
# Copyright (C) 2008, Lukas Durfina <lukas.durfina@gmail.com>
# Copyright (c) 2009, Fathi Boudra <fboudra@gmail.com>
#
# Redistribution and use is allowed according to the terms of the BSD license.
# For details see the accompanying COPYING-CMAKE-SCRIPTS file.
#

if(VLC_INCLUDE_DIR AND VLC_LIBRARIES)
    # in cache already
    set(VLC_FIND_QUIETLY TRUE)
endif(VLC_INCLUDE_DIR AND VLC_LIBRARIES)

# use pkg-config to get the directories and then use these values
# in the FIND_PATH() and FIND_LIBRARY() calls
if(NOT WIN32)
    find_package(PkgConfig)
    pkg_check_modules(VLC libvlc>=1.0.0)
    set(VLC_DEFINITIONS ${VLC_CFLAGS})

    # TODO add argument support to pass version on find_package
    include(MacroEnsureVersion)
    macro_ensure_version("1.0.0" ${VLC_VERSION} VLC_VERSION_OK)
else(NOT WIN32)
    set(VLC_VERSION_OK ON)
endif(NOT WIN32)


find_path(VLC_INCLUDE_DIR
          NAMES vlc.h
          PATHS 
          ${VLC_INCLUDE_DIRS}
          ${CMAKE_PREFIX_PATH}/include
          ${CMAKE_INCLUDE_PATH}
          PATH_SUFFIXES vlc)

find_library(VLC_LIBRARIES
             vlc
             PATHS 
             ${VLC_LIBRARY_DIRS}
             ${CMAKE_PREFIX_PATH}/lib
             ${CMAKE_LIBRARY_PATH})

if(VLC_VERSION_OK AND VLC_INCLUDE_DIR AND VLC_LIBRARIES)
    set(VLC_FOUND ON)
    message(STATUS "VLC library found")
else(VLC_VERSION_OK AND VLC_INCLUDE_DIR AND VLC_LIBRARIES)
    set(VLC_FOUND OFF)
    message(FATAL_ERROR "VLC library not found")
endif(VLC_VERSION_OK AND VLC_INCLUDE_DIR AND VLC_LIBRARIES)

include(FindPackageHandleStandardArgs)
find_package_handle_standard_args(VLC DEFAULT_MSG VLC_INCLUDE_DIR VLC_LIBRARIES)

# show the VLC_INCLUDE_DIR and VLC_LIBRARIES variables only in the advanced view
mark_as_advanced(VLC_INCLUDE_DIR VLC_LIBRARIES)
