/*  This file is part of the KDE project
    Copyright (C) 2009 Patrick Spendrin <ps_ml@gmx.de>
    
    based on the phonon media player

    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License as
    published by the Free Software Foundation; either version 2 of
    the License or (at your option) version 3 or any later version
    accepted by the membership of KDE e.V. (or its successor approved
    by the membership of KDE e.V.), Nokia Corporation (or its successors, 
    if any) and the KDE Free Qt Foundation, which shall act as a proxy 
    defined in Section 14 of version 3 of the license.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/

#include <QtCore/QUrl>
#include <QtGui/QApplication>
#include <QtGui/QWidget>

#include <phonon/audiooutput.h>
#include <phonon/mediaobject.h>
#include <phonon/path.h>

#include <cstdlib>

using Phonon::MediaObject;
using Phonon::AudioOutput;

class MediaPlayer : public QWidget
{
    public:
        MediaPlayer();
        void setUrl(const QUrl &url);
    private:
        Phonon::MediaObject *m_media;
        Phonon::AudioOutput *m_aoutput;
};

MediaPlayer::MediaPlayer()
    : QWidget(0)
{
    m_aoutput = new AudioOutput(Phonon::VideoCategory, this);
    m_media = new MediaObject(this);
    createPath(m_media, m_aoutput);
}

void MediaPlayer::setUrl(const QUrl &url)
{
    m_media->setCurrentSource(url);
    m_media->play();
}

int main(int argc, char ** argv)
{
    QApplication app(argc, argv);
    MediaPlayer foo;
    foo.show();

    QStringList args = app.arguments();
    if (args.count() == 2) {
        QUrl url(args[1]);
        if (url.isValid()) {
            foo.setUrl(url);
        }
    }
    return app.exec();
}
