#include <vlc/vlc.h>
#include <cstdio>
#include <cstdlib>
#include <cstring>
    
void raise(libvlc_exception_t * ex)
{
    if (libvlc_exception_raised (ex))
    {
         fprintf (stderr, "error: %s\n", libvlc_exception_get_message(ex));
         exit (-1);
    }
}

int main(int argc, char ** argv)
{
    if(argc < 2) {
        printf("Syntax:\n");
        printf("\t%s file:///path/to/file\n\n", argv[0]);
        printf("\tfile:///path/to/file can be replaced with any URL vlc understands.\n");
        printf("\tPlease make sure that the environment variable VLC_PLUGIN_PATH is set\n");
        printf("\tto your vlc installation's plugin path.\n\n");
        printf("\tcurrent value: VLC_PLUGIN_PATH=%s\n", getenv("VLC_PLUGIN_PATH"));
        return -1;
    }
    libvlc_exception_t _vlcexcep;
    libvlc_instance_t *_vlcinstance;
    libvlc_media_player_t *_mp;
    libvlc_media_t *_m;
    char pluginPath[1024];
    strcpy(pluginPath, "--plugin-path=");
    strcat(pluginPath, getenv("VLC_PLUGIN_PATH"));
    //preparation of the vlc command
    const char * const vlc_args[] = {
              "-I", "dummy", /* Don't use any interface */
              "--ignore-config", /* Don't use VLC's config */
              "--extraintf=logger", //log anything
              "--verbose=2", //be much more verbose then normal for debugging purpose
              pluginPath
              };

    libvlc_exception_init(&_vlcexcep);

    //create a new libvlc instance
    _vlcinstance=libvlc_new(sizeof(vlc_args) / sizeof(vlc_args[0]), vlc_args, &_vlcexcep);  //tricky calculation of the char space used
    raise (&_vlcexcep);
    
    // Create a media player playing environement 
    _mp = libvlc_media_player_new (_vlcinstance, &_vlcexcep);
    raise (&_vlcexcep);

    //the file has to be in one of the following formats /perhaps a little bit outdated)
    /*
    [file://]filename              Plain media file
    http://ip:port/file            HTTP URL
    ftp://ip:port/file             FTP URL
    mms://ip:port/file             MMS URL
    screen://                      Screen capture
    [dvd://][device][@raw_device]  DVD device
    [vcd://][device]               VCD device
    [cdda://][device]              Audio CD device
    udp:[[<source address>]@[<bind address>][:<bind port>]]
    */

    /* Create a new LibVLC media descriptor */
    _m = libvlc_media_new (_vlcinstance, argv[1], &_vlcexcep);
    raise(&_vlcexcep);
    
    libvlc_media_player_set_media (_mp, _m, &_vlcexcep);
    raise(&_vlcexcep);

    // /!\ Please note /!\
    //
    // passing the widget to the lib shows vlc at which position it should show up
    // vlc automatically resizes the video to the given size of the widget
    // and it even resizes it, if the size changes at the playing
    
    /* Play */
    libvlc_media_player_play (_mp, &_vlcexcep );
    raise(&_vlcexcep);

    do {
        libvlc_media_t *curMedia = libvlc_media_player_get_media (_mp, &_vlcexcep);
        libvlc_exception_clear(&_vlcexcep);
        if (curMedia == NULL)
            break;
    } while( 1==1 );

    libvlc_media_player_stop (_mp, &_vlcexcep);

    /* Free the media_player */
    libvlc_media_player_release (_mp);

    libvlc_release (_vlcinstance);
    raise (&_vlcexcep);

    return 0;
}